import 'package:autocomplete_textfield/autocomplete_textfield.dart';
import 'package:flutter/material.dart';

class AutoCompleteParams<T>{
  final String hintText;
  final Function( BuildContext, T ) _itemBuilder;
  final Function( T, String ) _itemFilter;
  final Function( T, T ) _itemSorter;
  final Function( T ) _itemSubmitted;
  double width;

  AutoCompleteParams(
    this.hintText,
    this._itemBuilder,
    this._itemFilter,
    this._itemSorter,
    this._itemSubmitted,
    {
      this.width = 70.0
    }
  );
}

class AutoComplete{

  static Widget getComponent<T>( List<T> _list, AutoCompleteParams<T> _params ){
    // https://medium.com/flutter-community/implementing-auto-complete-search-list-a8dd192bd5f6
    // https://medium.com/@sharansingh002/autocomplete-textfield-for-flutter-in-a-simple-way-9f3174dc3e0d
    GlobalKey<AutoCompleteTextFieldState<T>> key = new GlobalKey();

    AutoCompleteTextField searchTextField;
    
    if( null != _params ){
      searchTextField = AutoCompleteTextField<T>(
        key: key,
        style: TextStyle( color: Colors.black, fontSize: 16.0 ),
          decoration: InputDecoration(
          suffixIcon: Container(
            width: _params.width,
            child: Icon( Icons.search, color: Colors.black ),
          ),
          contentPadding: EdgeInsets.fromLTRB( 10.0, 30.0, 10.0, 20.0 ),
          filled: true,
          hintText: _params.hintText,
          hintStyle: TextStyle( color: Colors.grey ),
        ),
        itemBuilder: ( context, item ){
          return _params._itemBuilder( context, item );
        },
        itemFilter: ( item, query){
          return _params._itemFilter( item, query );
        },
        itemSorter: ( a, b ){
          return _params._itemSorter( a, b );
        },
        suggestions: _list,
        clearOnSubmit: false,
        itemSubmitted: ( item ) {
          _params._itemSubmitted( item );
        },
      );
    }
    else{
      print( "AutoComplete _params is null" );
    }

    return searchTextField;
  }
}