import 'package:flutter/material.dart';
import 'package:shared_package_flutter/list_view/list_view_error.dart';

enum ListViewType{
  separated,
  builder
}

class ListViewParams<T>{
  final int _itemCount;
  final ListViewType _listViewType;
  final Function( BuildContext, int ) _itemBuilder;

  ListViewParams(
    this._itemCount,
    this._listViewType,
    this._itemBuilder
  );
}

class ListViewComponent<T> extends StatelessWidget {
  final ListViewParams<T> _params;

  ListViewComponent( this._params, { Key key } ): super( key: key );

  Widget showSeparated( ){

    return ListView.separated(
      physics: AlwaysScrollableScrollPhysics( ),
      itemCount: this._params._itemCount,
      itemBuilder: ( context, index ){
        return this._params._itemBuilder( context, index );
      },
      separatorBuilder: ( context, index ){
        return Divider( thickness: 3 );
      }
    );
  }

  Widget showBuilder( ){

    return ListView.builder(
      physics: AlwaysScrollableScrollPhysics( ),
      itemCount: this._params._itemCount,
      itemBuilder: ( context, index ){
        return this._params._itemBuilder( context, index );
      }
    );
  }

  Widget show( ){

    if( this._params._listViewType == ListViewType.builder ){
      return showBuilder();
    }
    else{
      return showSeparated();
    }
  }

  @override
  Widget build( BuildContext context ){

    return null != this._params && this._params._itemCount > 0
      ? show( )
      : ListViewError.show( context, "Sem registros" );
  }
}